pub struct Table<T: SurrealRecord> { /* private fields */ }Expand description
Entry point to the query builder for a record type T — the value returned by
the derived T::table(). Each method starts a statement builder.
Implementations
Sourceimpl<T: SurrealRecord> Table<T>
impl<T: SurrealRecord> Table<T>
Sourcepub fn select(self, _cols: ColumnSet<T>) -> Select<T>
pub fn select(self, _cols: ColumnSet<T>) -> Select<T>
Begin a SELECT * FROM <table> (pass the derived T::all()).
Sourcepub fn project(self, fields: Vec<Projection>) -> Select<T>
pub fn project(self, fields: Vec<Projection>) -> Select<T>
Select an explicit projection list (SELECT <fields…> FROM table).
Sourcepub fn project_path(self, path: Path, alias: &'static str) -> Select<T>
pub fn project_path(self, path: Path, alias: &'static str) -> Select<T>
SELECT <path> AS <alias> FROM table — project a graph traversal.
A convenience for project(vec![Projection::aliased(path, alias)]).
Sourcepub fn upsert(self) -> Update<T>
pub fn upsert(self) -> Update<T>
UPSERT — update the matching record, or create it if it doesn’t exist.
Same builder surface as update (record/set/merge/
content/filter/returning/then_select).
Sourcepub fn search(
self,
field: impl Into<String>,
query: impl Into<String>,
) -> Search<T>
pub fn search( self, field: impl Into<String>, query: impl Into<String>, ) -> Search<T>
Begin a full-text Search over field for query
(SELECT … FROM <table> WHERE field @@ 'query'). Pair with a SEARCH
index on the field (see DefineIndex::search).
Sourcepub fn nearest(
self,
field: impl Into<String>,
vector: Vec<f32>,
) -> VectorSearch<T>
pub fn nearest( self, field: impl Into<String>, vector: Vec<f32>, ) -> VectorSearch<T>
Begin a vector K-nearest-neighbour VectorSearch over field for the
query vector (SELECT … FROM <table> WHERE field <|k|> [vector]). Pair
with an HNSW/MTREE index on the field (see DefineIndex::hnsw).